@@ -22,14 +22,18 @@
  */
 
 #include "config.h"
+#include "compositor-private.h"
 #include "mutter-plugin-manager.h"
 #include "prefs.h"
 #include "errors.h"
 #include "workspace.h"
 #include "mutter-module.h"
+#include "../core/window-private.h"
 
 #include <string.h>
 
+#include <clutter/x11/clutter-x11.h>
+
 /*
  * There is only one instace of each module per the process.
  */
@@ -337,6 +341,10 @@ mutter_plugin_manager_reload (MutterPluginManager *plugin_mgr)
    * plugins to unload? We are probably not going to have large numbers of
    * plugins loaded at the same time, so it might not be worth it.
    */
+
+  /* Prevent stale grabs on unloaded plugins */
+  mutter_check_end_modal (plugin_mgr->screen);
+
   mutter_plugin_manager_unload (plugin_mgr);
   return mutter_plugin_manager_load (plugin_mgr);
 }
@@ -399,6 +407,10 @@ mutter_plugin_manager_event_simple (MutterPluginManager *plugin_mgr,
 {
   GList *l = plugin_mgr->plugins;
   gboolean retval = FALSE;
+  MetaDisplay *display  = meta_screen_get_display (plugin_mgr->screen);
+
+  if (display->display_opening)
+    return FALSE;
 
   while (l)
     {
@@ -474,6 +486,10 @@ mutter_plugin_manager_event_maximize (MutterPluginManager *plugin_mgr,
 {
   GList *l = plugin_mgr->plugins;
   gboolean retval = FALSE;
+  MetaDisplay *display  = meta_screen_get_display (plugin_mgr->screen);
+
+  if (display->display_opening)
+    return FALSE;
 
   while (l)
     {
@@ -543,6 +559,10 @@ mutter_plugin_manager_switch_workspace (MutterPluginManager *plugin_mgr,
 {
   GList *l = plugin_mgr->plugins;
   gboolean retval = FALSE;
+  MetaDisplay *display  = meta_screen_get_display (plugin_mgr->screen);
+
+  if (display->display_opening)
+    return FALSE;
 
   while (l)
     {
@@ -585,12 +605,31 @@ mutter_plugin_manager_xevent_filter (MutterPluginManager *plugin_mgr,
                                      XEvent              *xev)
 {
   GList *l;
+  gboolean have_plugin_xevent_func;
 
   if (!plugin_mgr)
     return FALSE;
 
   l = plugin_mgr->plugins;
 
+  /* We need to make sure that clutter gets certain events, like
+   * ConfigureNotify on the stage window. If there is a plugin that
+   * provides an xevent_filter function, then it's the responsibility
+   * of that plugin to pass events to Clutter. Otherwise, we send the
+   * event directly to Clutter ourselves.
+   *
+   * What happens if there are two plugins with xevent_filter functions
+   * is undefined; in general, multiple competing plugins are something
+   * we don't support well or care much about.
+   *
+   * FIXME: Really, we should just always handle sending the event to
+   *  clutter if a plugin doesn't report the event as handled by
+   *  returning TRUE, but it doesn't seem worth breaking compatibility
+   *  of the plugin interface right now to achieve this; the way it is
+   *  now works fine in practice.
+   */
+  have_plugin_xevent_func = FALSE;
+
   while (l)
     {
       MutterPlugin      *plugin = l->data;
@@ -598,6 +637,7 @@ mutter_plugin_manager_xevent_filter (MutterPluginManager *plugin_mgr,
 
       if (klass->xevent_filter)
         {
+          have_plugin_xevent_func = TRUE;
           if (klass->xevent_filter (plugin, xev) == TRUE)
             return TRUE;
         }
@@ -605,5 +645,8 @@ mutter_plugin_manager_xevent_filter (MutterPluginManager *plugin_mgr,
       l = l->next;
     }
 
+  if (!have_plugin_xevent_func)
+    return clutter_x11_handle_event (xev) != CLUTTER_X11_FILTER_CONTINUE;
+
   return FALSE;
 }
