@@ -85,14 +85,6 @@ enum
   PROP_MCW_NO_SHADOW,
 };
 
-enum
-{
-  WINDOW_DESTROYED,
-  LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL] = { 0 };
-
 static void mutter_window_dispose    (GObject *object);
 static void mutter_window_finalize   (GObject *object);
 static void mutter_window_constructed (GObject *object);
@@ -105,6 +97,7 @@ static void mutter_window_get_property (GObject      *object,
 					   GValue       *value,
 					   GParamSpec   *pspec);
 
+static void     mutter_window_detach     (MutterWindow *self);
 static gboolean mutter_window_has_shadow (MutterWindow *self);
 
 static void mutter_window_clear_shape_region    (MutterWindow *self);
@@ -224,15 +217,6 @@ mutter_window_class_init (MutterWindowClass *klass)
   g_object_class_install_property (object_class,
                                    PROP_MCW_NO_SHADOW,
                                    pspec);
-
-  signals[WINDOW_DESTROYED] =
-    g_signal_new ("window-destroyed",
-		  G_TYPE_FROM_CLASS (object_class),
-                  G_SIGNAL_RUN_LAST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__VOID,
-		  G_TYPE_NONE, 0);
 }
 
 static void
@@ -950,19 +934,12 @@ mutter_window_effect_completed (MutterWindow *self,
     mutter_window_after_effects (self);
 }
 
-/**
- * mutter_window_detach:
- * @self: a #MutterWindow
- *
- * Called to drop our reference to a window backing pixmap that we
+/* Called to drop our reference to a window backing pixmap that we
  * previously obtained with XCompositeNameWindowPixmap. We do this
  * when the window is unmapped or when we want to update to a new
  * pixmap for a new size.
- *
- * This function is intended for internal use; if you are calling it externally,
- * you are likely doing something you should not.
  */
-void
+static void
 mutter_window_detach (MutterWindow *self)
 {
   MutterWindowPrivate *priv     = self->priv;
@@ -988,8 +965,6 @@ mutter_window_destroy (MutterWindow *self)
   MetaCompScreen      *info;
   MutterWindowPrivate *priv;
 
-  g_signal_emit (self, signals[WINDOW_DESTROYED], 0);
-
   priv = self->priv;
 
   window = priv->window;
