@@ -264,6 +264,13 @@ set_wm_check_hint (MetaScreen *screen)
   return Success;
 }
 
+static void
+unset_wm_check_hint (MetaScreen *screen)
+{
+  XDeleteProperty (screen->display->xdisplay, screen->xroot, 
+                   screen->display->atom__NET_SUPPORTING_WM_CHECK);
+}
+
 static int
 set_supported_hint (MetaScreen *screen)
 {
@@ -707,42 +714,13 @@ meta_screen_new (MetaDisplay *display,
   screen->compositor_data = NULL;
   screen->guard_window = None;
 
-  {
-    XFontStruct *font_info;
-    XGCValues gc_values;
-    gulong value_mask = 0;
-    
-    gc_values.subwindow_mode = IncludeInferiors;
-    value_mask |= GCSubwindowMode;
-    gc_values.function = GXinvert;
-    value_mask |= GCFunction;
-    gc_values.line_width = META_WIREFRAME_XOR_LINE_WIDTH;
-    value_mask |= GCLineWidth;
-
-    font_info = XLoadQueryFont (screen->display->xdisplay, "fixed");
-
-    if (font_info != NULL)
-      {
-        gc_values.font = font_info->fid;
-        value_mask |= GCFont;
-        XFreeFontInfo (NULL, font_info, 1);
-      }
-    else
-      meta_warning ("xserver doesn't have 'fixed' font.\n");
-
-    screen->root_xor_gc = XCreateGC (screen->display->xdisplay,
-                                     screen->xroot,
-                                     value_mask,
-                                     &gc_values);
-  }
-  
   screen->monitor_infos = NULL;
   screen->n_monitor_infos = 0;
   screen->last_monitor_index = 0;  
   
   reload_monitor_infos (screen);
   
-  meta_screen_set_cursor (screen, META_CURSOR_BUSY);
+  meta_screen_set_cursor (screen, META_CURSOR_DEFAULT);
 
   /* Handle creating a no_focus_window for this screen */  
   screen->no_focus_window =
@@ -831,7 +809,6 @@ meta_screen_free (MetaScreen *screen,
                   guint32     timestamp)
 {
   MetaDisplay *display;
-  XGCValues gc_values = { 0 };
 
   display = screen->display;
 
@@ -880,25 +857,14 @@ meta_screen_free (MetaScreen *screen,
     meta_warning (_("Could not release screen %d on display \"%s\"\n"),
                   screen->number, screen->display->name);
 
+  unset_wm_check_hint (screen);
+
   XDestroyWindow (screen->display->xdisplay,
                   screen->wm_sn_selection_window);
   
   if (screen->work_area_later != 0)
     g_source_remove (screen->work_area_later);
 
-
-  if (XGetGCValues (screen->display->xdisplay,
-                    screen->root_xor_gc,
-                    GCFont,
-                    &gc_values))
-    {
-      XUnloadFont (screen->display->xdisplay,
-                   gc_values.font);
-    }
-
-  XFreeGC (screen->display->xdisplay,
-           screen->root_xor_gc);
-  
   if (screen->monitor_infos)
     g_free (screen->monitor_infos);
   
@@ -3179,11 +3145,14 @@ meta_screen_set_cm_selection (MetaScreen *screen)
   char selection[32];
   Atom a;
 
+  screen->wm_cm_timestamp = meta_display_get_current_time_roundtrip (
+                                                               screen->display);
+
   g_snprintf (selection, sizeof(selection), "_NET_WM_CM_S%d", screen->number);
   meta_verbose ("Setting selection: %s\n", selection);
   a = XInternAtom (screen->display->xdisplay, selection, FALSE);
   XSetSelectionOwner (screen->display->xdisplay, a, 
-                      screen->wm_cm_selection_window, CurrentTime);
+                      screen->wm_cm_selection_window, screen->wm_cm_timestamp);
 }
 
 void
@@ -3194,7 +3163,8 @@ meta_screen_unset_cm_selection (MetaScreen *screen)
 
   g_snprintf (selection, sizeof(selection), "_NET_WM_CM_S%d", screen->number);
   a = XInternAtom (screen->display->xdisplay, selection, FALSE);
-  XSetSelectionOwner (screen->display->xdisplay, a, None, CurrentTime);
+  XSetSelectionOwner (screen->display->xdisplay, a,
+                      None, screen->wm_cm_timestamp);
 }
 
 GList *
