@@ -53,19 +53,16 @@ typedef enum
   META_PREF_VISUAL_BELL,
   META_PREF_AUDIBLE_BELL,
   META_PREF_VISUAL_BELL_TYPE,
-  META_PREF_REDUCED_RESOURCES,
   META_PREF_GNOME_ACCESSIBILITY,
   META_PREF_GNOME_ANIMATIONS,
   META_PREF_CURSOR_THEME,
   META_PREF_CURSOR_SIZE,
   META_PREF_COMPOSITING_MANAGER,
   META_PREF_RESIZE_WITH_RIGHT_BUTTON,
-#ifdef WITH_CLUTTER
-  META_PREF_CLUTTER_DISABLED,
+  META_PREF_FORCE_FULLSCREEN,
   META_PREF_CLUTTER_PLUGINS,
-#endif
   META_PREF_LIVE_HIDDEN_WINDOWS,
-  META_PREF_NO_TAB_POPUP,
+  META_PREF_NO_TAB_POPUP
 } MetaPreference;
 
 typedef void (* MetaPrefsChangedFunc) (MetaPreference pref,
@@ -93,7 +90,6 @@ gboolean                    meta_prefs_get_application_based  (void);
 gboolean                    meta_prefs_get_disable_workarounds (void);
 gboolean                    meta_prefs_get_auto_raise         (void);
 int                         meta_prefs_get_auto_raise_delay   (void);
-gboolean                    meta_prefs_get_reduced_resources  (void);
 gboolean                    meta_prefs_get_gnome_accessibility (void);
 gboolean                    meta_prefs_get_gnome_animations   (void);
 
@@ -120,6 +116,7 @@ void        meta_prefs_change_workspace_name (int         i,
 const char* meta_prefs_get_cursor_theme      (void);
 int         meta_prefs_get_cursor_size       (void);
 gboolean    meta_prefs_get_compositing_manager (void);
+gboolean    meta_prefs_get_force_fullscreen  (void);
 
 /**
  * Sets whether the compositor is turned on.
@@ -128,10 +125,7 @@ gboolean    meta_prefs_get_compositing_manager (void);
  */
 void meta_prefs_set_compositing_manager (gboolean whether);
 
-#ifdef WITH_CLUTTER
-
-gboolean meta_prefs_get_clutter_disabled (void);
-void     meta_prefs_set_clutter_disabled (gboolean whether);
+void meta_prefs_set_force_fullscreen (gboolean whether);
 
 GSList * meta_prefs_get_clutter_plugins (void);
 
@@ -150,8 +144,6 @@ void meta_prefs_set_clutter_plugins (GSList *list);
  */
 void meta_prefs_override_clutter_plugins (GSList *list);
 
-#endif
-
 gboolean meta_prefs_get_live_hidden_windows (void);
 void     meta_prefs_set_live_hidden_windows (gboolean whether);
 
