@@ -38,7 +38,7 @@ meta_edge_type_get_type (void)
     {
       static const GEnumValue values[] = {
         { META_EDGE_WINDOW, "META_EDGE_WINDOW", "window" },
-        { META_EDGE_XINERAMA, "META_EDGE_XINERAMA", "xinerama" },
+        { META_EDGE_MONITOR, "META_EDGE_MONITOR", "monitor" },
         { META_EDGE_SCREEN, "META_EDGE_SCREEN", "screen" },
         { 0, NULL, NULL }
       };
@@ -152,6 +152,29 @@ meta_debug_topic_get_type (void)
 
   return g_enum_type_id__volatile;
 }
+GType
+meta_later_type_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { META_LATER_RESIZE, "META_LATER_RESIZE", "resize" },
+        { META_LATER_BEFORE_REDRAW, "META_LATER_BEFORE_REDRAW", "before-redraw" },
+        { META_LATER_IDLE, "META_LATER_IDLE", "idle" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_enum_register_static (g_intern_static_string ("MetaLaterType"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
 
 /* enumerations from "include/common.h" */
 #include "include/common.h"
@@ -275,6 +298,7 @@ meta_grab_op_get_type (void)
         { META_GRAB_OP_CLICKING_UNABOVE, "META_GRAB_OP_CLICKING_UNABOVE", "clicking-unabove" },
         { META_GRAB_OP_CLICKING_STICK, "META_GRAB_OP_CLICKING_STICK", "clicking-stick" },
         { META_GRAB_OP_CLICKING_UNSTICK, "META_GRAB_OP_CLICKING_UNSTICK", "clicking-unstick" },
+        { META_GRAB_OP_COMPOSITOR, "META_GRAB_OP_COMPOSITOR", "compositor" },
         { 0, NULL, NULL }
       };
       GType g_enum_type_id;
@@ -1038,6 +1062,7 @@ meta_preference_get_type (void)
         { META_PREF_CURSOR_SIZE, "META_PREF_CURSOR_SIZE", "cursor-size" },
         { META_PREF_COMPOSITING_MANAGER, "META_PREF_COMPOSITING_MANAGER", "compositing-manager" },
         { META_PREF_RESIZE_WITH_RIGHT_BUTTON, "META_PREF_RESIZE_WITH_RIGHT_BUTTON", "resize-with-right-button" },
+        { META_PREF_FORCE_FULLSCREEN, "META_PREF_FORCE_FULLSCREEN", "force-fullscreen" },
         { META_PREF_CLUTTER_PLUGINS, "META_PREF_CLUTTER_PLUGINS", "clutter-plugins" },
         { META_PREF_LIVE_HIDDEN_WINDOWS, "META_PREF_LIVE_HIDDEN_WINDOWS", "live-hidden-windows" },
         { META_PREF_NO_TAB_POPUP, "META_PREF_NO_TAB_POPUP", "no-tab-popup" },
@@ -1338,5 +1363,31 @@ meta_atom_get_type (void)
   return g_enum_type_id__volatile;
 }
 
+/* enumerations from "include/mutter-plugin.h" */
+#include "include/mutter-plugin.h"
+
+GType
+meta_modal_options_get_type (void)
+{
+  static volatile gsize g_enum_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_enum_type_id__volatile))
+    {
+      static const GFlagsValue values[] = {
+        { META_MODAL_POINTER_ALREADY_GRABBED, "META_MODAL_POINTER_ALREADY_GRABBED", "pointer-already-grabbed" },
+        { META_MODAL_KEYBOARD_ALREADY_GRABBED, "META_MODAL_KEYBOARD_ALREADY_GRABBED", "keyboard-already-grabbed" },
+        { 0, NULL, NULL }
+      };
+      GType g_enum_type_id;
+
+      g_enum_type_id =
+        g_flags_register_static (g_intern_static_string ("MetaModalOptions"), values);
+
+      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
+    }
+
+  return g_enum_type_id__volatile;
+}
+
 /* Generated data ends here */
 
