@@ -656,7 +656,7 @@ meta_ui_window_should_not_cause_focus (Display *xdisplay,
   /* we shouldn't cause focus if we're an override redirect
    * toplevel which is not foreign
    */
-  if (window && gdk_window_get_type (window) == GDK_WINDOW_TEMP)
+  if (window && gdk_window_get_window_type (window) == GDK_WINDOW_TEMP)
     return TRUE;
   else
     return FALSE;
@@ -773,7 +773,7 @@ meta_ui_parse_accelerator (const char          *accel,
   *keycode = 0;
   *mask = 0;
 
-  if (strcmp (accel, "disabled") == 0)
+  if (!accel[0] || strcmp (accel, "disabled") == 0)
     return TRUE;
   
   meta_ui_accelerator_parse (accel, &gdk_sym, &gdk_code, &gdk_mask);
@@ -860,7 +860,7 @@ meta_ui_parse_modifier (const char          *accel,
   
   *mask = 0;
 
-  if (accel == NULL || strcmp (accel, "disabled") == 0)
+  if (accel == NULL || !accel[0] || strcmp (accel, "disabled") == 0)
     return TRUE;
   
   meta_ui_accelerator_parse (accel, &gdk_sym, &gdk_code, &gdk_mask);
